@@ -139,51 +139,15 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
         }
         // line 59
         yield "            </script>
-            <script>
-                (function() {
-                    const BRAND = 'Cause Buzz';
 
-                    // Replace title immediately
-                    function applyTitle() {
-                        const t = document.title.trim();
-                        if (t.indexOf(BRAND) === -1) {
-                            document.title = BRAND;
-                        }
-                    }
-
-                    // Run once on initial page load
-                    applyTitle();
-
-                    // Observe title changes (SPA navigation changes title after load)
-                    const titleEl = document.querySelector('title');
-                    if (titleEl) {
-                        new MutationObserver(applyTitle).observe(titleEl, {childList: true});
-                    }
-
-                    // Hook into Mautic's internal page load events (super important!)
-                    if (window.Mautic && typeof window.Mautic.onPageLoad === 'function') {
-                        const original = window.Mautic.onPageLoad;
-                        window.Mautic.onPageLoad = function(e) {
-                            original(e);
-                            applyTitle();
-                        };
-                    }
-
-                    // Also hook Stimulus (Mautic 5 admin uses it)
-                    document.addEventListener('stimulus:load', applyTitle);
-                    document.addEventListener('DOMContentLoaded', applyTitle);
-                    window.addEventListener('load', applyTitle);
-                })();
-            </script>
-            
             ";
-        // line 97
+        // line 61
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyClose");
         yield "
             ";
-        // line 98
+        // line 62
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/modal.html.twig", ["id" => "MauticSharedModal", "footerButtons" => true]);
-        // line 101
+        // line 65
         yield "
         </section>
     </body>
@@ -229,7 +193,7 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
      */
     public function getDebugInfo(): array
     {
-        return array (  204 => 40,  197 => 39,  187 => 101,  185 => 98,  181 => 97,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
+        return array (  168 => 40,  161 => 39,  151 => 65,  149 => 62,  145 => 61,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
     }
 
     public function getSourceContext(): Source
